@@ -1,12 +1,8 @@
+// SPDX-License-Identifier: LGPL-2.1-or-later
 /*
- * List all GPIO chips.
+ * This file is part of libgpiod.
  *
- * Copyright (C) 2017 Bartosz Golaszewski <bartekgola@gmail.com>
- *
- * This library is free software; you can redistribute it and/or modify it
- * under the terms of the GNU Lesser General Public License as published by
- * the Free Software Foundation; either version 2.1 of the License, or (at
- * your option) any later version.
+ * Copyright (C) 2017-2018 Bartosz Golaszewski <bartekgola@gmail.com>
  */
 
 #include <gpiod.h>
@@ -19,7 +15,7 @@
 static const struct option longopts[] = {
 	{ "help",	no_argument,	NULL,	'h' },
 	{ "version",	no_argument,	NULL,	'v' },
-	{ 0 },
+	{ GETOPT_NULL_LONGOPT },
 };
 
 static const char *const shortopts = "+hv";
@@ -39,8 +35,6 @@ int main(int argc, char **argv)
 	struct gpiod_chip *chip;
 	int optc, opti;
 
-	set_progname(argv[0]);
-
 	for (;;) {
 		optc = getopt_long(argc, argv, shortopts, longopts, &opti);
 		if (optc < 0)
@@ -71,10 +65,6 @@ int main(int argc, char **argv)
 		die_perror("unable to access GPIO chips");
 
 	gpiod_foreach_chip(iter, chip) {
-		if (gpiod_chip_iter_err(iter))
-			die_perror("error accessing gpiochip %s",
-				   gpiod_chip_iter_failed_chip(iter));
-
 		printf("%s [%s] (%u lines)\n",
 		       gpiod_chip_name(chip),
 		       gpiod_chip_label(chip),
